@@ -93,7 +93,7 @@ class Podman:
         _stdout, stderr, process = await self._run_podman(args, raise_on_err=False)
 
         if stderr:
-            logger.debug(f"{self.dsp_name}: {stderr.strip()}")
+            logger.debug(f"{self.dsp_name} {stderr.strip()}")
 
         return process.returncode == 0
 
@@ -124,10 +124,10 @@ class Podman:
     async def network_create(self, network):
         """Create a podman network if it does not exist."""
         if await self.network_exists(network):
-            logger.debug(f"{self.dsp_name}: Network '{network}' is present")
+            logger.debug(f"{self.dsp_name} Network '{network}' is present")
             return 0
 
-        logger.info(f"{self.dsp_name}: Creating podman network '{network}'")
+        logger.info(f"{self.dsp_name} Creating podman network '{network}'")
         args = ["network", "create", network]
         _stdout, _stderr, process = await self._run_podman(args, raise_on_err=False)
 
@@ -136,7 +136,7 @@ class Podman:
     async def network_remove(self, network):
         """Remove a podman network if it does exist."""
         if not await self.network_exists(network):
-            logger.debug(f"{self.dsp_name}: Network '{network}' does not exists")
+            logger.debug(f"{self.dsp_name} Network '{network}' does not exists")
             return True
 
         args = ["network", "remove", network]
@@ -148,13 +148,13 @@ class Podman:
         """Pull a container image."""
         args = ["pull", image]
         logger.info(
-            f"{self.dsp_name}: Pulling image '{image}'. This may take a while..."
+            f"{self.dsp_name} Pulling image '{image}'. This may take a while..."
         )
         _stdout, _stderr, process = await self._run_podman(args, raise_on_err=False)
         if process.returncode == 0:
-            logger.info(f"{self.dsp_name}: Pull of image '{image}' succeeded")
+            logger.info(f"{self.dsp_name} Pull of image '{image}' succeeded")
         else:
-            logger.error(f"{self.dsp_name}: Pull of image '{image}' failed")
+            logger.error(f"{self.dsp_name} Pull of image '{image}' failed")
 
         return process.returncode == 0
 
